quantizationtools.QGridSearchTree
=================================

.. inheritance-diagram:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.offsets

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.clear

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.copy

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.find_subtree_divisibility

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.get

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.has_key

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.items

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.iteritems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.iterkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.itervalues

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.keys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.pop

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.popitem

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.prune

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.setdefault

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.update

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.values

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.viewitems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.viewkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.viewvalues

   .. note:: Inherited from `__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__cmp__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__contains__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__delitem__

   .. note:: Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__eq__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__ge__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__getitem__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__gt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__iter__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__le__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__len__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__lt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__ne__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__repr__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__setitem__

   .. note:: Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridSearchTree.QGridSearchTree.QGridSearchTree.__str__

   .. note:: Inherited from `__builtin__.object`
